==> hugo-0.103.0.tar.gz: hugo-0.103.0/docs/content/en/commands/hugo_completion.md <==
---
title: "hugo completion"
slug: hugo_completion
url: /commands/hugo_completion/
---
## hugo completion

Generate the autocompletion script for the specified shell

### Synopsis

Generate the autocompletion script for hugo for the specified shell.
See each sub-command's help for details on how to use the generated script.


### Options

```
  -h, --help   help for completion
```

### Options inherited from parent commands

```
      --clock string               set the clock used by Hugo, e.g. --clock 2021-11-06T22:30:00.00+09:00
      --config string              config file (default is path/config.yaml|json|toml)
      --configDir string           config dir (default "config")
      --debug                      debug output
  -e, --environment string         build environment
      --ignoreVendorPaths string   ignores any _vendor for module paths matching the given Glob pattern
      --log                        enable Logging
      --logFile string             log File path (if set, logging enabled automatically)
      --quiet                      build in quiet mode
  -s, --source string              filesystem path to read files relative from
      --themesDir string           filesystem path to themes directory
  -v, --verbose                    verbose output
      --verboseLog                 verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site
* [hugo completion bash](/commands/hugo_completion_bash/)	 - Generate the autocompletion script for bash
* [hugo completion fish](/commands/hugo_completion_fish/)	 - Generate the autocompletion script for fish
* [hugo completion powershell](/commands/hugo_completion_powershell/)	 - Generate the autocompletion script for powershell
* [hugo completion zsh](/commands/hugo_completion_zsh/)	 - Generate the autocompletion script for zsh

==> hugo_0.111.3.orig.tar.gz: hugo-0.111.3/docs/content/en/commands/hugo_completion.md <==
---
title: "hugo completion"
slug: hugo_completion
url: /commands/hugo_completion/
---
## hugo completion

Generate the autocompletion script for the specified shell

### Synopsis

Generate the autocompletion script for hugo for the specified shell.
See each sub-command's help for details on how to use the generated script.


### Options

```
  -h, --help   help for completion
```

### Options inherited from parent commands

```
      --clock string               set the clock used by Hugo, e.g. --clock 2021-11-06T22:30:00.00+09:00
      --config string              config file (default is hugo.yaml|json|toml)
      --configDir string           config dir (default "config")
      --debug                      debug output
  -e, --environment string         build environment
      --ignoreVendorPaths string   ignores any _vendor for module paths matching the given Glob pattern
      --log                        enable Logging
      --logFile string             log File path (if set, logging enabled automatically)
      --quiet                      build in quiet mode
  -s, --source string              filesystem path to read files relative from
      --themesDir string           filesystem path to themes directory
  -v, --verbose                    verbose output
      --verboseLog                 verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site
* [hugo completion bash](/commands/hugo_completion_bash/)	 - Generate the autocompletion script for bash
* [hugo completion fish](/commands/hugo_completion_fish/)	 - Generate the autocompletion script for fish
* [hugo completion powershell](/commands/hugo_completion_powershell/)	 - Generate the autocompletion script for powershell
* [hugo completion zsh](/commands/hugo_completion_zsh/)	 - Generate the autocompletion script for zsh
